======================
Django-hotsauce 0.9.4
======================

:Author: Etienne Robillard <tkadm30@yandex.com>
:Version: 0.9.4

Welcome to the Django-hotsauce developer's handbook! This is a work-in-progress
document and may contains errors and/or incompleted chapters, etc. You're
invited to send feedback or suggestions about this document.

Thanks for reading!

.. toctree::

    :maxdepth: 3


    handbook/install
    handbook/getting-started
    handbook/configuration/advanced-configuration
    handbook/templates/mako
    handbook/cheatsheet
    handbook/deployment

    reference/controllers/index
    reference/datastore
    reference/authentication/index
    reference/dbapi/schevo
    reference/dbapi/schevo-initdb
    reference/urlmap

